@@ -8,7 +8,9 @@ import re
 from version import Version
 from logging import debugLogger as logger
 
-class DistributionNotSupportedError(Exception):
+
+class DistributionNotSupportedError(Exception):  # pragma: no cover
+
     """
     This distribution is not supported.
     """
@@ -20,7 +22,9 @@ class DistributionNotSupportedError(Exception):
     def __str__(self):
         return self.distro + ". " + DistributionNotSupportedError.PATCH_MESSAGE
 
+
 class PackageNotFoundError(Exception):
+
     """
     Error finding the requested package.
     """
@@ -29,32 +33,35 @@ class PackageNotFoundError(Exception):
 global packageDb
 global distro
 
-class PackageDb:
+
+class PackageDb(object):
+
     """
     Class to abstract the details of whatever software package database is in
     use (RPM, APT, etc)
     """
+
     def __init__(self):
         self.prefix = '/usr'
         self.localePrefixes = [self.prefix + '/share/locale']
 
     def getVersion(self, packageName):
         """
-        Method to get the version of an installed package as a Version 
-        instance (or raise an exception if not found)
-        
+        Method to get the version of an installed package as a Version
+         instance (or raise an exception if not found)
+
         Note: does not know about distributions' internal revision numbers.
         """
         raise NotImplementedError
 
     def getFiles(self, packageName):
         """
-        Method to get a list of filenames owned by the package, or raise an 
-        exception if not found.
+        Method to get a list of filenames owned by the package, or raise an
+         exception if not found.
         """
         raise NotImplementedError
 
-    def getMoFiles(self, locale = None):
+    def getMoFiles(self, locale=None):
         """
         Method to get a list of all .mo files on the system, optionally for a
         specific locale.
@@ -68,7 +75,8 @@ class PackageDb:
                     moFiles[dirName + '/' + fName] = None
 
         for localePrefix in self.localePrefixes:
-            if locale: localePrefix = localePrefix + '/' + locale
+            if locale:
+                localePrefix = localePrefix + '/' + locale
             os.path.walk(localePrefix, appendIfMoFile, moFiles)
 
         return moFiles.keys()
@@ -81,7 +89,9 @@ class PackageDb:
         """
         raise NotImplementedError
 
-class _RpmPackageDb(PackageDb):
+
+class _RpmPackageDb(PackageDb):  # pragma: no cover
+
     def __init__(self):
         PackageDb.__init__(self)
 
@@ -90,14 +100,14 @@ class _RpmPackageDb(PackageDb):
         ts = rpm.TransactionSet()
         for header in ts.dbMatch("name", packageName):
             return Version.fromString(header["version"])
-        raise PackageNotFoundError, packageName
+        raise PackageNotFoundError(packageName)
 
     def getFiles(self, packageName):
         import rpm
         ts = rpm.TransactionSet()
         for header in ts.dbMatch("name", packageName):
             return header["filenames"]
-        raise PackageNotFoundError, packageName
+        raise PackageNotFoundError(packageName)
 
     def getDependencies(self, packageName):
         import rpm
@@ -116,13 +126,15 @@ class _RpmPackageDb(PackageDb):
                 # this requirement:
                 for depPackageHeader in ts.dbMatch("provides", requirement):
                     depName = depPackageHeader['name']
-                    if depName!=packageName:
+                    if depName != packageName:
                         # Add to the Hash with a dummy value
-                        result[depName]=None
+                        result[depName] = None
             return result.keys()
-        raise PackageNotFoundError, packageName
+        raise PackageNotFoundError(packageName)
+
 
 class _AptPackageDb(PackageDb):
+
     def __init__(self):
         PackageDb.__init__(self)
         self.cache = None
@@ -135,20 +147,21 @@ class _AptPackageDb(PackageDb):
         packages = self.cache.Packages
         for package in packages:
             if package.Name == packageName:
-                import re
-                verString = re.match('.*Ver:\'(.*)-.*\' Section:', str(package.CurrentVer)).group(1)
+                verString = re.match(
+                    '.*Ver:\'(.*)-.*\' Section:', str(package.CurrentVer)).group(1)
                 return Version.fromString(verString)
-        raise PackageNotFoundError, packageName
+        raise PackageNotFoundError(packageName)
 
     def getFiles(self, packageName):
         files = []
         list = os.popen('dpkg -L %s' % packageName).readlines()
         if not list:
-            raise PackageNotFoundError, packageName
+            raise PackageNotFoundError(packageName)
         else:
             for line in list:
                 file = line.strip()
-                if file: files.append(file)
+                if file:
+                    files.append(file)
             return files
 
     def getDependencies(self, packageName):
@@ -164,7 +177,7 @@ class _AptPackageDb(PackageDb):
             if package.Name == packageName:
                 current = package.CurrentVer
                 if not current:
-                    raise PackageNotFoundError, packageName
+                    raise PackageNotFoundError(packageName)
                 depends = current.DependsList
                 list = depends['Depends']
                 for dependency in list:
@@ -173,52 +186,63 @@ class _AptPackageDb(PackageDb):
                     result[name] = None
         return result.keys()
 
+
 class _UbuntuAptPackageDb(_AptPackageDb):
+
     def __init__(self):
         _AptPackageDb.__init__(self)
         self.localePrefixes.append(self.prefix + '/share/locale-langpack')
 
-class _PortagePackageDb(PackageDb):
+
+class _PortagePackageDb(PackageDb):  # pragma: no cover
+
     def __init__(self):
         PackageDb.__init__(self)
 
     def getVersion(self, packageName):
-        # the portage utilities are almost always going to be in 
+        # the portage utilities are almost always going to be in
         # /usr/lib/portage/pym
         import sys
-        sys.path.append ('/usr/lib/portage/pym')
+        sys.path.append('/usr/lib/portage/pym')
         import portage
-        # FIXME: this takes the first package returned in the list, in the 
-        # case that there are slotted packages, and removes the leading 
+        # FIXME: this takes the first package returned in the list, in the
+        # case that there are slotted packages, and removes the leading
         # category such as 'sys-apps'
-        gentooPackageName = portage.db["/"]["vartree"].dbapi.match(packageName)[0].split('/')[1];
+        gentooPackageName = portage.db["/"][
+            "vartree"].dbapi.match(packageName)[0].split('/')[1]
         # this removes the distribution specific versioning returning only the
         # upstream version
         upstreamVersion = portage.pkgsplit(gentooPackageName)[1]
-        #print "Version of package is: " + upstreamVersion
-        return Version.fromString(upstreamVersion);
+        # print "Version of package is: " + upstreamVersion
+        return Version.fromString(upstreamVersion)
+
+
+class _ConaryPackageDb(PackageDb):  # pragma: no cover
 
-class _ConaryPackageDb(PackageDb):
     def __init__(self):
         PackageDb.__init__(self)
 
     def getVersion(self, packageName):
-        import conary
         from conaryclient import ConaryClient
         client = ConaryClient()
         dbVersions = client.db.getTroveVersionList(packageName)
         if not len(dbVersions):
-            raise PackageNotFoundError, packageName
+            raise PackageNotFoundError(packageName)
         return dbVersions[0].trailingRevision().asString().split("-")[0]
 
 # getVersion not implemented because on Solaris multiple modules are installed
 # in single packages, so it is hard to tell what version number of a specific
 # module.
-class _SolarisPackageDb(PackageDb):
+
+
+class _SolarisPackageDb(PackageDb):  # pragma: no cover
+
     def __init__(self):
         PackageDb.__init__(self)
 
-class JhBuildPackageDb(PackageDb):
+
+class JhBuildPackageDb(PackageDb):  # pragma: no cover
+
     def __init__(self):
         PackageDb.__init__(self)
         prefixes = []
@@ -236,84 +260,103 @@ class JhBuildPackageDb(PackageDb):
                 result[line.strip()] = None
         return result.keys()
 
-class Distro:
+
+class Distro(object):
+
     """
     Class representing a distribution.
 
     Scripts may want to do arbitrary logic based on whichever distro is in use
-    (e.g. handling differences in names of packages, distribution-specific 
-    patches, etc.)
+    (e.g. handling differences in names of packages, distribution-specific
+     patches, etc.)
 
-    We can either create methods in the Distro class to handle these, or we 
-    can use constructs like isinstance(distro, Ubuntu) to handle this. We can
+    We can either create methods in the Distro class to handle these, or we
+     can use constructs like isinstance(distro, Ubuntu) to handle this. We can
     even create hierarchies of distro subclasses to handle this kind of thing
     (could get messy fast though)
     """
 
-class Fedora(Distro):
+
+class Fedora(Distro):  # pragma: no cover
+
     def __init__(self):
         self.packageDb = _RpmPackageDb()
 
-class RHEL(Fedora):
+
+class RHEL(Fedora):  # pragma: no cover
     pass
 
-class Debian(Distro):
+
+class Debian(Distro):  # pragma: no cover
+
     def __init__(self):
         self.packageDb = _AptPackageDb()
 
+
 class Ubuntu(Debian):
+
     def __init__(self):
         self.packageDb = _UbuntuAptPackageDb()
 
-class Suse(Distro):
+
+class Suse(Distro):  # pragma: no cover
+
     def __init__(self):
         self.packageDb = _RpmPackageDb()
 
-class Gentoo(Distro):
+
+class Gentoo(Distro):  # pragma: no cover
+
     def __init__(self):
         self.packageDb = _PortagePackageDb()
 
-class Conary(Distro):
+
+class Conary(Distro):  # pragma: no cover
+
     def __init__(self):
         self.packageDb = _ConaryPackageDb()
 
-class Solaris(Distro):
+
+class Solaris(Distro):  # pragma: no cover
+
     def __init__(self):
         self.packageDb = _SolarisPackageDb()
 
-class JHBuild(Distro):
+
+class JHBuild(Distro):  # pragma: no cover
+
     def __init__(self):
         self.packageDb = JhBuildPackageDb()
 
+
 def detectDistro():
-    logger.log("Detecting distribution:", newline = False)
+    logger.log("Detecting distribution:", newline=False)
 
     if os.environ.get("CERTIFIED_GNOMIE", "no") == "yes":
-        distro = JHBuild()
+        distro = JHBuild()  # pragma: no cover
     elif os.path.exists("/etc/SuSE-release"):
-        distro = Suse()
+        distro = Suse()  # pragma: no cover
     elif os.path.exists("/etc/fedora-release"):
-        distro = Fedora()
+        distro = Fedora()  # pragma: no cover
     elif os.path.exists("/etc/redhat-release"):
-        distro = RHEL()
+        distro = RHEL()  # pragma: no cover
     elif os.path.exists("/usr/share/doc/ubuntu-minimal"):
         distro = Ubuntu()
-    elif os.path.exists("/etc/debian_version"):
-        distro = Debian()
-    elif os.path.exists("/etc/gentoo-release"):
-        distro = Gentoo()
-    elif os.path.exists("/etc/slackware-version"):
-        raise DistributionNotSupportedError("Slackware")
-    elif os.path.exists("/var/lib/conarydb/conarydb"):
-        distro = Conary()
-    elif os.path.exists ("/etc/release") and \
-            re.match(".*Solaris", open ("/etc/release").readline()):
-        distro = Solaris()
+    elif os.path.exists("/etc/debian_version"):  # pragma: no cover
+        distro = Debian()  # pragma: no cover
+    elif os.path.exists("/etc/gentoo-release"):  # pragma: no cover
+        distro = Gentoo()  # pragma: no cover
+    elif os.path.exists("/etc/slackware-version"):  # pragma: no cover
+        raise DistributionNotSupportedError("Slackware")  # pragma: no cover
+    elif os.path.exists("/var/lib/conarydb/conarydb"):  # pragma: no cover
+        distro = Conary()  # pragma: no cover
+    elif os.path.exists("/etc/release") and \
+            re.match(".*Solaris", open("/etc/release").readline()):  # pragma: no cover
+        distro = Solaris()  # pragma: no cover
     else:
-        raise DistributionNotSupportedError("Unknown")
+        raise DistributionNotSupportedError("Unknown")  # pragma: no cover
     logger.log(distro.__class__.__name__)
     return distro
 
 distro = detectDistro()
 packageDb = distro.packageDb
-
