@@ -3,8 +3,12 @@
 Author: Zack Cerza <zcerza@redhat.com>"""
 __author__ = "Zack Cerza <zcerza@redhat.com>"
 
+from __builtin__ import file
+
 spacer = ' '
-def plain (node, fileName = None):
+
+
+def plain(node, fileName=None):
     """
     Plain-text dump. The hierarchy is represented through indentation.
     """
@@ -15,12 +19,15 @@ def plain (node, fileName = None):
         for child in node.children:
             crawl(child, depth + 1)
 
-    def dumpFile(item, depth): _file.write(spacer*depth + str(item) + '\n')
-    def dumpStdOut(item, depth): print spacer*depth + str(item)
+    def dumpFile(item, depth):
+        _file.write(spacer * depth + str(item) + '\n')
+
+    def dumpStdOut(item, depth):
+        print(spacer * depth + str(item))
     if fileName:
         dump = dumpFile
         _file = file(fileName, 'w')
-    else: dump = dumpStdOut
-    
-    crawl(node, 0)
+    else:
+        dump = dumpStdOut
 
+    crawl(node, 0)
