@@ -12,20 +12,23 @@ David Malcolm <dmalcolm@redhat.com>
 import os
 import sys
 import time
-import datetime
 from config import config
 import codecs
 
 # Timestamp class for file logs
-class TimeStamp:
+
+
+class TimeStamp(object):
+
     """
     Generates timestamps tempfiles and log entries
     """
+
     def __init__(self):
         self.now = "0"
         self.timetup = time.localtime()
 
-    def zeroPad(self, int, width = 2):
+    def zeroPad(self, int, width=2):
         """
         Pads an integer 'int' with zeroes, up to width 'width'.
 
@@ -34,12 +37,12 @@ class TimeStamp:
         It will not truncate. If you call zeroPad(100, 2), '100' will be returned.
         """
         if int < 10 ** width:
-            return ("0" * (width - len(str(int))) ) + str(int)
+            return ("0" * (width - len(str(int)))) + str(int)
         else:
             return str(int)
 
     # file stamper
-    def fileStamp(self, filename, addTime = True):
+    def fileStamp(self, filename, addTime=True):
         """
         Generates a filename stamp in the format of filename_YYYYMMDD-hhmmss.
         A format of filename_YYYYMMDD can be used instead by specifying addTime = False.
@@ -50,9 +53,11 @@ class TimeStamp:
         # Should produce rel-eng style filestamps
         # format it all pretty by chopping the tuple
         fieldCount = 3
-        if addTime: fieldCount = fieldCount + 3
+        if addTime:
+            fieldCount = fieldCount + 3
         for i in range(fieldCount):
-            if i == 3: self.now = self.now + '-'
+            if i == 3:
+                self.now = self.now + '-'
             self.now = self.now + self.zeroPad(self.timetup[i])
         return self.now
 
@@ -72,7 +77,6 @@ class TimeStamp:
             elif i == 1 or i == 2:
                 self.now = self.now + "." + self.zeroPad(self.timetup[i])
             else:
-                x = self.timetup[i]
                 # make the " " between Day and Hour and put in the hour
                 if i == 3:
                     self.now = self.now + " " + self.zeroPad(self.timetup[i])
@@ -81,12 +85,15 @@ class TimeStamp:
                     self.now = self.now + ":" + self.zeroPad(self.timetup[i])
         return self.now
 
-class Logger:
+
+class Logger(object):
+
     """
     Writes entries to standard out.
     """
     stamper = TimeStamp()
-    def __init__(self, logName, file = False, stdOut = True):
+
+    def __init__(self, logName, file=False, stdOut=True):
         """
         name: the name of the log
         file: The file object to log to.
@@ -94,11 +101,13 @@ class Logger:
         """
         self.logName = logName
         self.stdOut = stdOut
-        self.file = file # Handle to the logfile
-        if not self.file: return
+        self.file = file  # Handle to the logfile
+        if not self.file:
+            return
 
         scriptName = config.scriptName
-        if not scriptName: scriptName = 'log'
+        if not scriptName:
+            scriptName = 'log'
         self.fileName = scriptName
 
         # check to see if we can write to the logDir
@@ -106,13 +115,13 @@ class Logger:
             self.findUniqueName()
         else:
             # If path doesn't exist, raise an exception
-            raise IOError, \
-                    "Log path %s does not exist or is not a directory" % config.logDir
+            raise IOError(
+                "Log path %s does not exist or is not a directory" % config.logDir)
 
     def findUniqueName(self):
         # generate a logfile name and check if it already exists
         self.fileName = config.logDir + self.stamper.fileStamp(self.fileName) \
-                + '_' + self.logName
+            + '_' + self.logName
         i = 0
         while os.path.exists(self.fileName):
             # Append the pathname
@@ -126,40 +135,51 @@ class Logger:
 
     def createFile(self):
         # Try to create the file and write the header info
-        print "Creating logfile at %s ..." % self.fileName
-        self.file = codecs.open(self.fileName, mode = 'wb', encoding = \
-                'utf-8')
+        print("Creating logfile at %s ..." % self.fileName)
+        self.file = codecs.open(self.fileName, mode='wb', encoding=
+                                'utf-8')
         self.file.write("##### " + os.path.basename(self.fileName) + '\n')
         self.file.flush()
 
-    def log(self, message, newline = True, force = False):
+    def log(self, message, newline=True, force=False):
         """
         Hook used for logging messages. Might eventually be a virtual
         function, but nice and simple for now.
 
         If force is True, log to a file irrespective of config.logDebugToFile.
         """
-        message = message.decode('utf-8', 'replace')
+        try:
+            message = message.decode('utf-8', 'replace')
+        except UnicodeEncodeError:
+            pass
+
 
         # Try to open and write the result to the log file.
         if isinstance(self.file, bool) and (force or config.logDebugToFile):
             self.createFile()
 
         if force or config.logDebugToFile:
-            if newline: self.file.write(message + '\n')
-            else: self.file.write(message + ' ')
+            if newline:
+                self.file.write(message + '\n')
+            else:
+                self.file.write(message + ' ')
             self.file.flush()
 
         if self.stdOut and config.logDebugToStdOut:
-            if newline: print message
-            else: print message,
+            if newline:
+                print(message)
+            else:
+                print(message)
+
 
 class ResultsLogger(Logger):
+
     """
     Writes entries into the Dogtail log
     """
-    def __init__(self, stdOut = True):
-        Logger.__init__(self, 'results', file = True, stdOut = stdOut)
+
+    def __init__(self, stdOut=True):
+        Logger.__init__(self, 'results', file=True, stdOut=stdOut)
 
     # Writes the result of a test case comparison to the log
     def log(self, entry):
@@ -177,15 +197,19 @@ class ResultsLogger(Logger):
             value = value[0]
             entry = str(key) + ":      " + str(value)
         else:
-            raise ValueError, entry
-            print "Method argument requires a 1 {key: value} dict. Supplied argument not one {key: value}"
+            raise ValueError(entry)
+            print(
+                "Method argument requires a 1 {key: value} dict. Supplied argument not one {key: value}")
 
-        Logger.log(self, self.stamper.entryStamp() + "      " + entry, force = True)
+        Logger.log(self, self.stamper.entryStamp() + "      " + entry,
+                   force=True)
 
 debugLogger = Logger('debug', config.logDebugToFile)
 
 import traceback
-def exceptionHook(exc, value, tb):
+
+
+def exceptionHook(exc, value, tb):  # pragma: no cover
     tbStringList = traceback.format_exception(exc, value, tb)
     tbString = ''.join(tbStringList)
     debugLogger.log(tbString)
