@@ -16,89 +16,117 @@ import gi
 gi.require_version('Gtk', '3.0')
 gi.require_version('Gdk', '3.0')
 
-import sys
-from gi.repository import Gtk
 from gi.repository import Gdk
 from config import config
 from utils import doDelay
 from logging import debugLogger as logger
 from pyatspi import Registry as registry
 from pyatspi import (KEY_SYM, KEY_PRESS, KEY_PRESSRELEASE, KEY_RELEASE)
+from exceptions import ValueError
+from __builtin__ import unicode, unichr
+
 
 def doTypingDelay():
     doDelay(config.typingDelay)
 
-def click (x, y, button = 1):
+
+def checkCoordinates(x, y):
+    if x < 0 or y < 0:
+        raise ValueError(
+            "Attempting to generate a mouse event at negative coordinates: (%s,%s)" % (x, y))
+
+
+def click(x, y, button=1, check=True):
     """
     Synthesize a mouse button click at (x,y)
     """
-    logger.log("Mouse button %s click at (%s,%s)"%(button,x,y))
+    if check:
+        checkCoordinates(x, y)
+    logger.log("Mouse button %s click at (%s,%s)" % (button, x, y))
     registry.generateMouseEvent(x, y, 'b%sc' % button)
     doDelay(config.actionDelay)
 
-def doubleClick (x, y, button = 1):
+
+def doubleClick(x, y, button=1, check=True):
     """
     Synthesize a mouse button double-click at (x,y)
     """
-    logger.log("Mouse button %s doubleclick at (%s,%s)"%(button,x,y))
-    registry.generateMouseEvent(x,y, 'b%sd' % button)
+    if check:
+        checkCoordinates(x, y)
+    logger.log("Mouse button %s doubleclick at (%s,%s)" % (button, x, y))
+    registry.generateMouseEvent(x, y, 'b%sd' % button)
     doDelay()
 
-def press (x, y, button = 1):
+
+def press(x, y, button=1, check=True):
     """
     Synthesize a mouse button press at (x,y)
     """
-    logger.log("Mouse button %s press at (%s,%s)"%(button,x,y))
-    registry.generateMouseEvent(x,y, 'b%sp' % button)
+    if check:
+        checkCoordinates(x, y)
+    logger.log("Mouse button %s press at (%s,%s)" % (button, x, y))
+    registry.generateMouseEvent(x, y, 'b%sp' % button)
     doDelay()
 
-def release (x, y, button = 1):
+
+def release(x, y, button=1, check=True):
     """
     Synthesize a mouse button release at (x,y)
     """
-    logger.log("Mouse button %s release at (%s,%s)"%(button,x,y))
-    registry.generateMouseEvent(x,y, 'b%sr' % button)
+    if check:
+        checkCoordinates(x, y)
+    logger.log("Mouse button %s release at (%s,%s)" % (button, x, y))
+    registry.generateMouseEvent(x, y, 'b%sr' % button)
     doDelay()
 
-def absoluteMotion (x, y, mouseDelay=None):
+
+def absoluteMotion(x, y, mouseDelay=None, check=True):
     """
     Synthesize mouse absolute motion to (x,y)
     """
-    logger.log("Mouse absolute motion to (%s,%s)"%(x,y))
-    registry.generateMouseEvent(x,y, 'abs')
+    if check:
+        checkCoordinates(x, y)
+    logger.log("Mouse absolute motion to (%s,%s)" % (x, y))
+    registry.generateMouseEvent(x, y, 'abs')
     if mouseDelay:
         doDelay(mouseDelay)
     else:
         doDelay()
 
-def relativeMotion (x, y, mouseDelay=None):
-    logger.log("Mouse relative motion of (%s,%s)"%(x,y))
-    registry.generateMouseEvent(x,y, 'rel')
+
+def relativeMotion(x, y, mouseDelay=None):
+    logger.log("Mouse relative motion of (%s,%s)" % (x, y))
+    registry.generateMouseEvent(x, y, 'rel')
     if mouseDelay:
         doDelay(mouseDelay)
     else:
         doDelay()
 
-def drag(fromXY, toXY, button = 1):
+
+def drag(fromXY, toXY, button=1, check=True):
     """
     Synthesize a mouse press, drag, and release on the screen.
     """
-    logger.log("Mouse button %s drag from %s to %s"%(button, fromXY, toXY))
+    logger.log("Mouse button %s drag from %s to %s" % (button, fromXY, toXY))
 
-    (x,y) = fromXY
-    press (x, y, button)
-    #doDelay()
+    (x, y) = fromXY
+    press(x, y, button, check)
+    # doDelay()
 
-    (x,y) = toXY
-    absoluteMotion(x,y)
+    (x, y) = toXY
+    absoluteMotion(x, y, check=check)
     doDelay()
 
-    release (x, y, button)
+    release(x, y, button, check)
     doDelay()
 
+
 def typeText(string):
     """
     Types the specified string, one character at a time.
+    Please note, you may have to set a higher typing delay,
+    if your machine misses/switches the characters typed.
+    Needed sometimes on slow setups/VMs typing non-ASCII utf8 chars.
     """
     if not isinstance(string, unicode):
         string = string.decode('utf-8')
@@ -106,47 +134,61 @@ def typeText(string):
         pressKey(char)
 
 keyNameAliases = {
-    'enter' : 'Return',
-    'esc' : 'Escape',
-    'alt' : 'Alt_L',
-    'control' : 'Control_L',
-    'ctrl' : 'Control_L',
-    'shift' : 'Shift_L',
-    'del' : 'Delete',
-    'ins' : 'Insert',
-    'pageup' : 'Page_Up',
-    'pagedown' : 'Page_Down',
-    ' ' : 'space',
-    '\t' : 'Tab',
-    '\n' : 'Return'
+    'enter': 'Return',
+    'esc': 'Escape',
+    'alt': 'Alt_L',
+    'control': 'Control_L',
+    'ctrl': 'Control_L',
+    'shift': 'Shift_L',
+    'del': 'Delete',
+    'ins': 'Insert',
+    'pageup': 'Page_Up',
+    'pagedown': 'Page_Down',
+    ' ': 'space',
+    '\t': 'Tab',
+    '\n': 'Return'
 }
 
-def keySymToUniChar(keySym):
+
+# TODO: Dead code
+def keySymToUniChar(keySym):  # pragma: no cover
     i = Gdk.keyval_to_unicode(keySym)
-    if i: UniChar = unichr(i)
-    else: UniChar = ''
+    if i:
+        UniChar = unichr(i)
+    else:
+        UniChar = ''
     return UniChar
 
+
 def uniCharToKeySym(uniChar):
     # OK, if it's not actually unicode we can fix that, right?
-    if not isinstance(uniChar, unicode): uniChar = unicode(uniChar)
+    if not isinstance(uniChar, unicode):
+        uniChar = unicode(uniChar, 'utf-8')
     i = ord(uniChar)
     keySym = Gdk.unicode_to_keyval(i)
     return keySym
 
-def keySymToKeyName(keySym):
+
+# dead code
+def keySymToKeyName(keySym):  # pragma: no cover
     return Gdk.keyval_name(keySym)
 
+
 def keyNameToKeySym(keyName):
-    try:
-        keyName = keyNameAliases.get(keyName.lower(), keyName)
-        keySym = Gdk.keyval_from_name(keyName)
-        if not keySym: keySym = getattr(Gdk, keyName)
-    except AttributeError:
-        try: keySym = uniCharToKeySym(keyName)
-        except TypeError: raise KeyError, keyName
+    keyName = keyNameAliases.get(keyName.lower(), keyName)
+    keySym = Gdk.keyval_from_name(keyName)
+    # various error 'codes' returned for non-recognized chars in versions of GTK3.X
+    if keySym == 0xffffff or keySym == 0x0 or keySym is None:
+        try:
+            keySym = uniCharToKeySym(keyName)
+        except: # not even valid utf-8 char
+            try: # Last attempt run at a keyName ('Meta_L', 'Dash' ...)
+                keySym = getattr(Gdk, 'KEY_' + keyName)
+            except AttributeError:
+                raise KeyError(keyName)
     return keySym
 
+
 def keyNameToKeyCode(keyName):
     """
     Use GDK to get the keycode for a given keystring.
@@ -158,10 +200,13 @@ def keyNameToKeyCode(keyName):
     function for nonprintable keys anyway.
     """
     keymap = Gdk.Keymap.get_for_display(Gdk.Display.get_default())
-    entries = keymap.get_entries_for_keyval( \
-                Gdk.keyval_from_name(keyName))
-    try: return entries[1][0].keycode
-    except TypeError: pass
+    entries = keymap.get_entries_for_keyval(
+        Gdk.keyval_from_name(keyName))
+    try:
+        return entries[1][0].keycode
+    except TypeError:
+        pass
+
 
 def pressKey(keyName):
     """
@@ -174,6 +219,7 @@ def pressKey(keyName):
     registry.generateKeyboardEvent(keySym, None, KEY_SYM)
     doTypingDelay()
 
+
 def keyCombo(comboString):
     """
     Generates the appropriate keyboard events to simulate a user pressing the
@@ -192,11 +238,10 @@ def keyCombo(comboString):
     for s in strings:
         if not hasattr(Gdk, s):
             if not hasattr(Gdk, 'KEY_' + s):
-                raise ValueError, "Cannot find key %s" % s
+                raise ValueError("Cannot find key %s" % s)
     modifiers = strings[:-1]
     finalKey = strings[-1]
     for modifier in modifiers:
-
         code = keyNameToKeyCode(modifier)
         registry.generateKeyboardEvent(code, None, KEY_PRESS)
     code = keyNameToKeyCode(finalKey)
@@ -205,4 +250,3 @@ def keyCombo(comboString):
         code = keyNameToKeyCode(modifier)
         registry.generateKeyboardEvent(code, None, KEY_RELEASE)
     doDelay()
-
