@@ -5,16 +5,18 @@ Subclass these classes if you want to create application wrappers, e.g.:
 http://svn.gnome.org/viewvc/dogtail-tests/trunk/appwrappers/dogtail/appwrappers/gedit.py?view=markup
 """
 __author__ = "Zack Cerza <zcerza@redhat.com>"
-import tree
 import Accessibility
 
-def makeWrapperClass(wrappedClass, name):
+
+def makeWrapperClass(wrappedClass, name):  # pragma: no cover
     class klass(object):
+
         def __init__(self, obj):
             self.obj = obj
 
         def __getattr__(self, name):
-            if name == 'obj': return self.__dict__['obj']
+            if name == 'obj':
+                return self.__dict__['obj']
             return getattr(self.obj, name)
 
         def __setattr__(self, name, value):
@@ -26,7 +28,6 @@ def makeWrapperClass(wrappedClass, name):
     klass.__name__ = name
     return klass
 
-Application = makeWrapperClass(Accessibility.Application, \
-        "WrappedApplication")
+Application = makeWrapperClass(Accessibility.Application,
+                               "WrappedApplication")
 Node = makeWrapperClass(Accessibility.Accessible, "WrappedNode")
-
